
def zip_longest(*iterables, fillvalue=None):
    # This function zips multiple iterables (lists, tuples, etc.) together, 
    # filling in missing values with a specified fillvalue if the iterables are of unequal length.
    
    # Python's zip function stops creating pairs when the shortest iterable is exhausted.
    # zip_longest extends this behavior to allow for a specified fillvalue for shorter iterables.
    
    iterators = [iter(it) for it in iterables]
    while True:
        result = []
        for it in iterators:
            try:
                result.append(next(it))
            except StopIteration:
                result.append(fillvalue)
        yield tuple(result)



